<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation>Olhe</translation>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation>Janela única</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Roster position</source>
        <translation>Posição do Roster</translation>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation>Escolha a posição do Roster no modo de Janela Única</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation>Mudar para aba anterior</translation>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation>Mudar para próxima aba</translation>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation>Mostrar/esconder Roster</translation>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation>Mudar o foco entre Roster e abas</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
</context>
</TS>